@@ -8,6 +8,7 @@ module Gitlab
   class Request
     include HTTParty
     format :json
+    maintain_method_across_redirects true
     headers 'Accept' => 'application/json', 'Content-Type' => 'application/x-www-form-urlencoded'
     parser(proc { |body, _| parse(body) })
 
@@ -37,7 +38,7 @@ module Gitlab
       raise Error::Parsing, 'The response is not a valid JSON'
     end
 
-    %w[get post put delete].each do |method|
+    %w[get post put patch delete].each do |method|
       define_method method do |path, options = {}|
         params = options.dup
 
@@ -48,14 +49,25 @@ module Gitlab
           params[:headers].merge!(authorization_header)
         end
 
-        validate self.class.send(method, @endpoint + path, params)
+        retries_left = params[:ratelimit_retries] || 3
+        begin
+          response = self.class.send(method, endpoint + path, params)
+          validate response
+        rescue Gitlab::Error::TooManyRequests => e
+          retries_left -= 1
+          raise e if retries_left.zero?
+
+          wait_time = response.headers['Retry-After'] || 2
+          sleep(wait_time.to_i)
+          retry
+        end
       end
     end
 
     # Checks the response code for common errors.
     # Returns parsed response for successful requests.
     def validate(response)
-      error_klass = Error::STATUS_MAPPINGS[response.code]
+      error_klass = Error.klass(response)
       raise error_klass, response if error_klass
 
       parsed = response.parsed_response
@@ -67,7 +79,7 @@ module Gitlab
     # Sets a base_uri and default_params for requests.
     # @raise [Error::MissingCredentials] if endpoint not set.
     def request_defaults(sudo = nil)
-      raise Error::MissingCredentials, 'Please set an endpoint to API' unless @endpoint
+      raise Error::MissingCredentials, 'Please set an endpoint to API' unless endpoint
 
       self.class.default_params sudo: sudo
       self.class.default_params.delete(:sudo) if sudo.nil?
@@ -79,12 +91,12 @@ module Gitlab
     #
     # @raise [Error::MissingCredentials] if private_token and auth_token are not set.
     def authorization_header
-      raise Error::MissingCredentials, 'Please provide a private_token or auth_token for user' unless @private_token
+      raise Error::MissingCredentials, 'Please provide a private_token or auth_token for user' unless private_token
 
-      if @private_token.size < 21
-        { 'PRIVATE-TOKEN' => @private_token }
+      if private_token.size < 21
+        { 'PRIVATE-TOKEN' => private_token }
       else
-        { 'Authorization' => "Bearer #{@private_token}" }
+        { 'Authorization' => "Bearer #{private_token}" }
       end
     end
 
