@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-describe Gitlab::Client do
+RSpec.describe Gitlab::Client do
   describe '.groups' do
     before do
       stub_get('/groups', 'groups')
@@ -42,7 +42,7 @@ describe Gitlab::Client do
 
       it 'gets the correct resource' do
         expect(a_post('/groups')
-            .with(body: { path: 'gitlab-path', name: 'GitLab-Group' })).to have_been_made
+          .with(body: { path: 'gitlab-path', name: 'GitLab-Group' })).to have_been_made
       end
 
       it 'returns information about a created group' do
@@ -59,8 +59,8 @@ describe Gitlab::Client do
 
       it 'gets the correct resource' do
         expect(a_post('/groups')
-                 .with(body: { path: 'gitlab-path', name: 'GitLab-Group',
-                               description: 'gitlab group description' })).to have_been_made
+          .with(body: { path: 'gitlab-path', name: 'GitLab-Group',
+                        description: 'gitlab group description' })).to have_been_made
       end
 
       it 'returns information about a created group' do
@@ -126,6 +126,40 @@ describe Gitlab::Client do
     end
   end
 
+  describe '.all_group_members' do
+    before do
+      stub_get('/groups/3/members/all', 'group_members')
+      @all_members = Gitlab.all_group_members(3)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/groups/3/members/all')).to have_been_made
+    end
+
+    it "returns information about a group's members" do
+      expect(@all_members).to be_a Gitlab::PaginatedResponse
+      expect(@all_members.size).to eq(2)
+      expect(@all_members[1].name).to eq('John Smith')
+    end
+  end
+
+  describe '.group_descendants' do
+    before do
+      stub_get('/groups/3/descendant_groups', 'group_descendants')
+      @descendants = Gitlab.group_descendants(3)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/groups/3/descendant_groups')).to have_been_made
+    end
+
+    it "returns information about a group's descendants" do
+      expect(@descendants).to be_a Gitlab::PaginatedResponse
+      expect(@descendants.size).to eq(2)
+      expect(@descendants[1].name).to eq('Foobar Group 2')
+    end
+  end
+
   describe '.group_billable_members' do
     before do
       stub_get('/groups/3/billable_members', 'group_billable_members')
@@ -184,7 +218,7 @@ describe Gitlab::Client do
 
     it 'gets the correct resource' do
       expect(a_put('/groups/3/members/1')
-          .with(body: { access_level: '50' })).to have_been_made
+        .with(body: { access_level: '50' })).to have_been_made
     end
 
     it 'returns information about the edited member' do
@@ -258,19 +292,17 @@ describe Gitlab::Client do
   end
 
   describe '.edit_group' do
-    context 'using group ID' do
-      before do
-        stub_put('/groups/1', 'group_edit').with(body: { description: 'An interesting group' })
-        @edited_project = Gitlab.edit_group(1, description: 'An interesting group')
-      end
+    before do
+      stub_put('/groups/1', 'group_edit').with(body: { description: 'An interesting group' })
+      @edited_project = Gitlab.edit_group(1, description: 'An interesting group')
+    end
 
-      it 'gets the correct resource' do
-        expect(a_put('/groups/1').with(body: { description: 'An interesting group' })).to have_been_made
-      end
+    it 'gets the correct resource' do
+      expect(a_put('/groups/1').with(body: { description: 'An interesting group' })).to have_been_made
+    end
 
-      it 'returns information about an edited group' do
-        expect(@edited_project.description).to eq('An interesting group')
-      end
+    it 'returns information about an edited group' do
+      expect(@edited_project.description).to eq('An interesting group')
     end
   end
 
@@ -345,4 +377,160 @@ describe Gitlab::Client do
       expect(a_delete('/groups/1/ldap_group_links/ldap/all')).to have_been_made
     end
   end
+
+  describe '.group_custom_attributes' do
+    before do
+      stub_get('/groups/2/custom_attributes', 'group_custom_attributes')
+      @custom_attributes = Gitlab.group_custom_attributes(2)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/groups/2/custom_attributes')).to have_been_made
+    end
+
+    it 'returns a information about a custom_attribute of group' do
+      expect(@custom_attributes.first.key).to eq 'somekey'
+      expect(@custom_attributes.last.value).to eq('somevalue2')
+    end
+  end
+
+  describe '.group_custom_attribute' do
+    before do
+      stub_get('/groups/2/custom_attributes/some_new_key', 'group_custom_attribute')
+      @custom_attribute = Gitlab.group_custom_attribute('some_new_key', 2)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/groups/2/custom_attributes/some_new_key')).to have_been_made
+    end
+
+    it 'returns a information about the single custom_attribute of group' do
+      expect(@custom_attribute.key).to eq 'some_new_key'
+      expect(@custom_attribute.value).to eq('some_new_value')
+    end
+  end
+
+  describe '.add_custom_attribute' do
+    describe 'with group ID' do
+      before do
+        stub_put('/groups/2/custom_attributes/some_new_key', 'group_custom_attribute')
+        @custom_attribute = Gitlab.add_group_custom_attribute('some_new_key', 'some_new_value', 2)
+      end
+
+      it 'gets the correct resource' do
+        body = { value: 'some_new_value' }
+        expect(a_put('/groups/2/custom_attributes/some_new_key').with(body: body)).to have_been_made
+        expect(a_put('/groups/2/custom_attributes/some_new_key')).to have_been_made
+      end
+
+      it 'returns information about a new custom attribute' do
+        expect(@custom_attribute.key).to eq 'some_new_key'
+        expect(@custom_attribute.value).to eq 'some_new_value'
+      end
+    end
+  end
+
+  describe '.delete_custom_attribute' do
+    describe 'with group ID' do
+      before do
+        stub_delete('/groups/2/custom_attributes/some_new_key', 'group_custom_attribute')
+        @custom_attribute = Gitlab.delete_group_custom_attribute('some_new_key', 2)
+      end
+
+      it 'gets the correct resource' do
+        expect(a_delete('/groups/2/custom_attributes/some_new_key')).to have_been_made
+      end
+
+      it 'returns information about a deleted custom_attribute' do
+        expect(@custom_attribute).to be_truthy
+      end
+    end
+  end
+
+  describe '.list_group_hooks' do
+    before do
+      stub_get('/groups/3/hooks', 'group_hooks')
+      @hooks = Gitlab.list_group_hooks(3)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/groups/3/hooks')).to have_been_made
+    end
+
+    it 'returns a list of registered group hooks based on the group id' do
+      expect(@hooks).to be_a Gitlab::PaginatedResponse
+      expect(@hooks.size).to eq(1)
+      expect(@hooks[0].url).to eq('http://example.com/hook')
+    end
+  end
+
+  describe '.group_hook(group_id, hook_id)' do
+    before do
+      stub_get('/groups/3/hooks/1', 'group_hook')
+      @hook = Gitlab.group_hook(3, 1)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/groups/3/hooks/1')).to have_been_made
+    end
+
+    it 'returns information about the requested group hook' do
+      expect(@hook).to be_a Gitlab::ObjectifiedHash
+      expect(@hook.url).to eq('http://example.com/hook')
+    end
+  end
+
+  describe '.add_group_hook(group_id, url, options)' do
+    before do
+      stub_post('/groups/3/hooks', 'group_hook')
+      @hook = Gitlab.add_group_hook(3, 'http://example.com', {
+                                      push_events: true,
+                                      push_events_branch_filter: 'main',
+                                      enable_ssl_verification: true,
+                                      token: 'foofoofoo1234'
+                                    })
+    end
+
+    it 'creates the correct resource' do
+      expect(a_post('/groups/3/hooks')
+        .with(body: { url: 'http://example.com', push_events: true, push_events_branch_filter: 'main', enable_ssl_verification: true, token: 'foofoofoo1234' })).to have_been_made
+    end
+
+    it 'returns the created group hook matching the format of GET hook' do
+      expect(@hook).to be_a Gitlab::ObjectifiedHash
+      expect(@hook.url).to eq('http://example.com/hook')
+    end
+  end
+
+  describe '.edit_group_hook(group_id, hook_id, url)' do
+    before do
+      stub_post('/groups/3/hooks/1', 'group_hook')
+      @hook = Gitlab.edit_group_hook(3, 1, 'http://example.com', { push_events: false, token: 'foofoofoo1234' })
+    end
+
+    it 'updates the correct resource' do
+      expect(a_post('/groups/3/hooks/1')
+        .with(body: { url: 'http://example.com', push_events: false, token: 'foofoofoo1234' })).to have_been_made
+    end
+
+    it 'returns the updated group hook resource' do
+      expect(@hook).to be_a Gitlab::ObjectifiedHash
+      expect(@hook.url).to eq('http://example.com/hook')
+    end
+  end
+
+  describe '.delete_group_hook(group_id, hook_id)' do
+    before do
+      stub_delete('/groups/3/hooks/1', 'group_hook_delete')
+      @hook = Gitlab.delete_group_hook(3, 1)
+    end
+
+    it 'delete the resource' do
+      expect(a_delete('/groups/3/hooks/1')).to have_been_made
+    end
+
+    it 'returns false in test but in real life it returns status without a body which is converted to ObjectifiedHash' do
+      expect(@hook).to eq(false)
+    end
+  end
 end
