@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-describe Gitlab::Client do
+RSpec.describe Gitlab::Client do
   describe '.user_merge_requests' do
     before do
       stub_get('/merge_requests', 'merge_requests')
@@ -77,6 +77,18 @@ describe Gitlab::Client do
     end
   end
 
+  describe '.create_merge_request_pipeline' do
+    before do
+      stub_post('/projects/3/merge_requests/2/pipelines', 'pipeline_create')
+    end
+
+    it 'returns information about created merge request pipeline' do
+      @pipeline = Gitlab.create_merge_request_pipeline(3, 2)
+      expect(@pipeline.yaml_errors).to be_nil
+      expect(@pipeline.status).to eq('pending')
+    end
+  end
+
   describe '.create_merge_request' do
     before do
       stub_post('/projects/3/merge_requests', 'merge_request')
@@ -376,6 +388,37 @@ describe Gitlab::Client do
     end
   end
 
+  describe '.delete_merge_request' do
+    before do
+      stub_request(:delete, 'https://api.example.com/projects/3/merge_requests/2').to_return(body: '')
+      @merge_request = Gitlab.delete_merge_request(3, 2)
+    end
+
+    it 'deletes the correct resource' do
+      expect(a_delete('/projects/3/merge_requests/2')).to have_been_made
+    end
+
+    it 'returns nothing' do
+      expect(@merge_request).to be_falsy
+    end
+  end
+
+  describe '.merge_request_diffs' do
+    before do
+      stub_get('/projects/3/merge_requests/105/diffs', 'merge_request_diffs')
+      @versions = Gitlab.merge_request_diffs(3, 105)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/projects/3/merge_requests/105/diffs')).to have_been_made
+    end
+
+    it 'returns an array of the diffs' do
+      expect(@versions.length).to eq(2)
+      expect(@versions.first.old_path).to eq('README')
+    end
+  end
+
   describe '.merge_request_diff_versions' do
     before do
       stub_get('/projects/3/merge_requests/105/versions', 'merge_request_diff_versions')
@@ -407,4 +450,21 @@ describe Gitlab::Client do
       expect(@diff.diffs.first['old_path']).to eq('LICENSE')
     end
   end
+
+  describe '.rebase_merge_request' do
+    before do
+      stub_put('/projects/3/merge_requests/105/rebase', 'merge_request_rebase')
+        .with(body: { skip_ci: true })
+      @response = Gitlab.rebase_merge_request(3, 105, skip_ci: true)
+    end
+
+    it 'gets correct resource' do
+      expect(a_put('/projects/3/merge_requests/105/rebase')
+        .with(body: { skip_ci: true })).to have_been_made
+    end
+
+    it 'returns rebase in progress response' do
+      expect(@response.rebase_in_progress).to be_truthy
+    end
+  end
 end
