@@ -2,13 +2,13 @@
 
 require 'spec_helper'
 
-describe Gitlab::PaginatedResponse do
+RSpec.describe Gitlab::PaginatedResponse do
   before do
     array = [1, 2, 3, 4]
     @paginated_response = described_class.new array
   end
 
-  it 'responds to *_page and has_*_page methods' do
+  it 'responds to total, *_page and has_*_page methods' do
     expect(@paginated_response).to respond_to :first_page
     expect(@paginated_response).to respond_to :last_page
     expect(@paginated_response).to respond_to :next_page
@@ -17,11 +17,12 @@ describe Gitlab::PaginatedResponse do
     expect(@paginated_response).to respond_to :has_last_page?
     expect(@paginated_response).to respond_to :has_next_page?
     expect(@paginated_response).to respond_to :has_prev_page?
+    expect(@paginated_response).to respond_to :total
   end
 
   describe '.parse_headers!' do
     it 'parses headers' do
-      @paginated_response.parse_headers!('Link' => '<http://example.com/api/v3/projects?page=1&per_page=5>; rel="first", <http://example.com/api/v3/projects?page=20&per_page=5>; rel="last"')
+      @paginated_response.parse_headers!('Link' => '<http://example.com/api/v3/projects?page=1&per_page=5>; rel="first", <http://example.com/api/v3/projects?page=20&per_page=5>; rel="last"', 'x-total' => '8')
       client = @paginated_response.client = double('client')
       first_page_response = double('first_page_response')
       last_page_response = double('last_page_response')
@@ -36,6 +37,7 @@ describe Gitlab::PaginatedResponse do
       expect(@paginated_response.last_page).to be last_page_response
       expect(@paginated_response.next_page).to be_nil
       expect(@paginated_response.prev_page).to be_nil
+      expect(@paginated_response.total).to eq('8')
     end
 
     context 'when the Link header endpoint does not match the configured endpoint' do
@@ -92,7 +94,7 @@ describe Gitlab::PaginatedResponse do
     end
   end
 
-  shared_context 'when performing limited pagination returning an array' do
+  shared_context 'when performing with a block limited pagination returning an array' do
     before do
       next_page = double('next_page')
       allow(@paginated_response).to receive(:has_next_page?).and_return(true)
@@ -103,20 +105,16 @@ describe Gitlab::PaginatedResponse do
   end
 
   describe '.paginate_with_limit' do
-    include_context 'when performing limited pagination returning an array'
+    include_context 'when performing with a block limited pagination returning an array'
+
     it 'returns a limited array' do
       expect(@paginated_response.paginate_with_limit(3)).to contain_exactly(1, 2, 3)
     end
-  end
 
-  describe '.paginate_with_limit' do
-    include_context 'when performing limited pagination returning an array'
     it 'returns exactly the first page' do
       expect(@paginated_response.paginate_with_limit(4)).to contain_exactly(1, 2, 3, 4)
     end
-  end
 
-  describe '.paginate_with_limit' do
     it 'returns a page plus one' do
       next_page = double('next_page')
       allow(@paginated_response).to receive(:has_next_page?).and_return(true)
@@ -125,34 +123,15 @@ describe Gitlab::PaginatedResponse do
       allow(next_page).to receive(:to_ary).and_return([5])
       expect(@paginated_response.paginate_with_limit(5)).to contain_exactly(1, 2, 3, 4, 5)
     end
-  end
 
-  shared_context 'when performing limited pagination with a block' do
-    before do
-      next_page = double('next_page')
-      allow(@paginated_response).to receive(:has_next_page?).and_return(true)
-      allow(@paginated_response).to receive(:next_page).and_return(next_page)
-      allow(next_page).to receive(:has_next_page?).and_return(false)
-      allow(next_page).to receive(:to_ary).and_return([5, 6, 7, 8])
-    end
-  end
-
-  describe '.paginate_with_limit' do
-    include_context 'when performing limited pagination with a block'
     it 'iterates items with limit' do
       expect { |b| @paginated_response.paginate_with_limit(3, &b) }.to yield_successive_args(1, 2, 3)
     end
-  end
 
-  describe '.paginate_with_limit' do
-    include_context 'when performing limited pagination with a block'
     it 'iterates exactly the first page' do
       expect { |b| @paginated_response.paginate_with_limit(4, &b) }.to yield_successive_args(1, 2, 3, 4)
     end
-  end
 
-  describe '.paginate_with_limit' do
-    include_context 'when performing limited pagination with a block'
     it 'iterates the first page plus one' do
       expect { |b| @paginated_response.paginate_with_limit(5, &b) }.to yield_successive_args(1, 2, 3, 4, 5)
     end
